==> general_lib-0.0.28.tar.gz: lib/tcp/tcp_client_data.dart <==
/* <!-- START LICENSE -->


Program Ini Di buat Oleh DEVELOPER Dari PERUSAHAAN GLOBAL CORPORATION 
Social Media: 

- Youtube: https://youtube.com/@Global_Corporation 
- Github: https://github.com/globalcorporation
- TELEGRAM: https://t.me/GLOBAL_CORP_ORG_BOT

Seluruh kode disini di buat 100% murni tanpa jiplak / mencuri kode lain jika ada akan ada link komment di baris code

Jika anda mau mengedit pastikan kredit ini tidak di hapus / di ganti!

Jika Program ini milik anda dari hasil beli jasa developer di (Global Corporation / apapun itu dari turunan itu jika ada kesalahan / bug / ingin update segera lapor ke sub)

Misal anda beli Beli source code di Slebew CORPORATION anda lapor dahulu di slebew jangan lapor di GLOBAL CORPORATION!


<!-- END LICENSE --> */
// ignore_for_file: non_constant_identifier_names, unused_local_variable, empty_catches

import 'dart:async';
import 'dart:typed_data';

import 'package:general_lib/scheme/socket_connection.dart';
// import 'package:general_lib/scheme/scheme.dart';
import 'package:universal_io/io.dart';

abstract class TcpSocketClientData {
  late Socket socket;
  dynamic host;
  int port;
  dynamic sourceAddress;
  int sourcePort = 0;
  Duration? timeout;
  bool isConnect = false;
  Map connect_data = {};
  late Duration ping_interval;
  TcpSocketClientData({
    required this.host,
    required this.port,
    this.sourceAddress,
    this.sourcePort = 0,
    this.timeout,
    Map? connectData,
    Duration? pingInterval,
  });
  
  Future<void> connect({
    // void Function(dynamic data)? onDataUpdate,
    // void Function(Map data)? onSocketConnection,
    required FutureOr<void> Function(Uint8List data) onSocketData,
    required FutureOr<void> Function(SocketConnection socketConnection) onSocketConnection,
    Duration delayDuration = const Duration(milliseconds: 500),
  }) async {
    return;
  }

  Future<void> send({
    required List<int> value,
    Duration durationTimeOut = const Duration(minutes: 1),
    Duration durationDelay = const Duration(milliseconds: 1),
  }) async {
    return;
  }

  void sendSync({
    required List<int> value,
    Duration durationTimeOut = const Duration(minutes: 1),
  }) {
    return;
  }
}

==> general_lib-0.0.30.tar.gz: lib/tcp/tcp_client_data.dart <==
/* <!-- START LICENSE -->


Program Ini Di buat Oleh DEVELOPER Dari PERUSAHAAN GLOBAL CORPORATION 
Social Media: 

- Youtube: https://youtube.com/@Global_Corporation 
- Github: https://github.com/globalcorporation
- TELEGRAM: https://t.me/GLOBAL_CORP_ORG_BOT

Seluruh kode disini di buat 100% murni tanpa jiplak / mencuri kode lain jika ada akan ada link komment di baris code

Jika anda mau mengedit pastikan kredit ini tidak di hapus / di ganti!

Jika Program ini milik anda dari hasil beli jasa developer di (Global Corporation / apapun itu dari turunan itu jika ada kesalahan / bug / ingin update segera lapor ke sub)

Misal anda beli Beli source code di Slebew CORPORATION anda lapor dahulu di slebew jangan lapor di GLOBAL CORPORATION!


<!-- END LICENSE --> */
// ignore_for_file: non_constant_identifier_names, unused_local_variable, empty_catches

import 'dart:async';
import 'dart:typed_data';

import 'package:general_lib/scheme/socket_connection.dart';
// import 'package:general_lib/scheme/scheme.dart';
import 'package:universal_io/io.dart';

abstract class TcpSocketClientData {
  late Socket socket;
  dynamic host;
  int port;
  dynamic sourceAddress;
  int sourcePort = 0;
  Duration? timeout;
  bool isConnect = false;
  Map connect_data = {};
  late Duration ping_interval;
  TcpSocketClientData({
    required this.host,
    required this.port,
    this.sourceAddress,
    this.sourcePort = 0,
    this.timeout,
    Map? connectData,
    Duration? pingInterval,
  });

  Future<void> connect({
    // void Function(dynamic data)? onDataUpdate,
    // void Function(Map data)? onSocketConnection,
    required FutureOr<void> Function(Uint8List data) onSocketData,
    required FutureOr<void> Function(SocketConnection socketConnection)
        onSocketConnection,
    Duration delayDuration = const Duration(milliseconds: 500),
  }) async {
    return;
  }

  Future<void> send({
    required List<int> value,
    Duration durationTimeOut = const Duration(minutes: 1),
    Duration durationDelay = const Duration(milliseconds: 1),
  }) async {
    return;
  }

  void sendSync({
    required List<int> value,
    Duration durationTimeOut = const Duration(minutes: 1),
  }) {
    return;
  }
}
